==> spirit_hub-0.1.1.6.tar.gz: spirit_hub-0.1.1.6/e2e/cypress/support/commands.js <==
// ***********************************************
// This example commands.js shows you how to
// create various custom commands and overwrite
// existing commands.
//
// For more comprehensive examples of custom
// commands please read more here:
// https://on.cypress.io/custom-commands
// ***********************************************
//
//
import '@4tw/cypress-drag-drop';

Cypress.Commands.add('login', (email, password) => {
  cy.visit('/users/sign_in');

  cy.get('input#user_username').type(email);
  cy.get('input#user_password').type(password);
  cy.get('a#login').click();
});

Cypress.Commands.add('addAuthHeader', token => {
  if (token) {
    Cypress.env('auth-user-token', token);
    cy.intercept({ url: '/spirit_hub/**', middleware: true }, req => {
      req.headers['X-auth-user-token'] = token;
      req.continue();
    }).as('authenticatedRequest');
  }
});

Cypress.Commands.add('waitForTurboResponse', () => {
  cy.window().then(win => {
    return new Cypress.Promise(resolve => {
      const handler = () => {
        win.removeEventListener('turbo:before-fetch-response', handler);
        resolve();
      };

      win.addEventListener('turbo:before-fetch-response', handler);
    });
  });
});

//
//
// -- This is a child command --
// Cypress.Commands.add("drag", { prevSubject: 'element'}, (subject, options) => { ... })
//
//
// -- This is a dual command --
// Cypress.Commands.add("dismiss", { prevSubject: 'optional'}, (subject, options) => { ... })
//
//
// -- This is will overwrite an existing command --
// Cypress.Commands.overwrite("visit", (originalFn, url, options) => { ... })

==> spirit_hub-1.0.0.5.tar.gz: spirit_hub-1.0.0.5/e2e/cypress/support/commands.js <==
// ***********************************************
// This example commands.js shows you how to
// create various custom commands and overwrite
// existing commands.
//
// For more comprehensive examples of custom
// commands please read more here:
// https://on.cypress.io/custom-commands
// ***********************************************
//
//
import '@4tw/cypress-drag-drop';

Cypress.Commands.add('login', (email, password) => {
  cy.visit('/users/sign_in');

  cy.get('input#user_username').type(email);
  cy.get('input#user_password').type(password);
  cy.get('a#login').click();
});

Cypress.Commands.add('forceLogin', details => {
  if (!details) {
    details = {};
  }

  if (!details.redirect_to) {
    details.redirect_to = '/spirit_hub';
  }

  cy.visit('__cypress__/forceLogin', { method: 'POST', body: { email: details.email, redirect_to: details.redirect_to } });
});

Cypress.Commands.add('waitForTurboResponse', () => {
  cy.window().then(win => {
    return new Cypress.Promise(resolve => {
      const handler = () => {
        win.removeEventListener('turbo:before-fetch-response', handler);
        resolve();
      };

      win.addEventListener('turbo:before-fetch-response', handler);
    });
  });
});

//
//
// -- This is a child command --
// Cypress.Commands.add("drag", { prevSubject: 'element'}, (subject, options) => { ... })
//
//
// -- This is a dual command --
// Cypress.Commands.add("dismiss", { prevSubject: 'optional'}, (subject, options) => { ... })
//
//
// -- This is will overwrite an existing command --
// Cypress.Commands.overwrite("visit", (originalFn, url, options) => { ... })
